.. image:: https://travis-ci.org/praekelt/molo.svg?branch=develop
    :target: https://travis-ci.org/praekelt/molo
    :alt: Continuous Integration

.. image:: https://coveralls.io/repos/praekelt/molo/badge.png?branch=develop
    :target: https://coveralls.io/r/praekelt/molo?branch=develop
    :alt: Code Coverage

.. image:: https://readthedocs.org/projects/molo/badge/?version=latest
    :target: https://molo.readthedocs.org
    :alt: Molo Documentation

.. image:: https://badge.fury.io/py/molo.core.svg
    :target: http://badge.fury.io/py/molo.core
    :alt: Pypi Package
